@@ -8,20 +8,14 @@ from urllib.parse import urlparse, urlunsplit
 
 import yaml
 
-from hepdata_validator import Validator, ValidationMessage
+from hepdata_validator import Validator, ValidationMessage, YamlLoader, YamlDumper
 from .schema_resolver import JsonSchemaResolver
 from .schema_downloader import HTTPSchemaDownloader
 from .submission_file_validator import SubmissionFileValidator
 from .data_file_validator import DataFileValidator
 
-# We try to load using the CSafeLoader for speed improvements.
-try:
-    from yaml import CSafeLoader as Loader
-    from yaml import CSafeDumper as Dumper
-except ImportError:  # pragma: no cover
-    from yaml import SafeLoader as Loader
-    from yaml import SafeDumper as Dumper
 
+INDIVIDUAL_FILE_SIZE_LIMIT = 10485760
 
 class SchemaType(Enum):
     SUBMISSION = 'submission'
@@ -169,7 +163,7 @@ class FullSubmissionValidator(Validator):
             # Open the submission.yaml file and load all YAML documents.
             with open(self.submission_file_path, 'r') as submission_file:
                 try:
-                    self.submission_docs = list(yaml.load_all(submission_file, Loader=Loader))
+                    self.submission_docs = list(yaml.load_all(submission_file, Loader=YamlLoader))
                 except yaml.YAMLError as e:
                     self._add_validation_message(
                         file=self.submission_file_path,
@@ -205,12 +199,33 @@ class FullSubmissionValidator(Validator):
 
             # Check all files in directory are in included_files
             if not self.single_yaml_file and self.schema_version >= packaging_version.parse("1.1.0"):
+                # helper to check if a provided file is not meant to describe HEP data, but rather
+                # represents "extended attributes" (e.g.) as a result of BSD tar (default on MacOS)
+                # which creates these extra files when archiving files with extended attributes on
+                # HSF+ volumes (denoted by "@" in permission bits)
+                def is_ext_attr_file(f):
+                    # three conditions must be fulfilled
+                    # 1. the file must not be referenced in the submission (already checked below)
+                    # 2. the file name must have the format "._<actual_file>"
+                    prefix = "._"
+                    if not f.startswith(prefix):
+                        return False
+                    # 3. a file named "<actual_file>" must exist in the same directory
+                    if not os.path.isfile(os.path.join(self.directory, f[len(prefix):])):
+                        return False
+                    return True
+
                 for f in os.listdir(self.directory):
                     file_path = os.path.join(self.directory, f)
                     if file_path not in self.included_files:
                         self._add_validation_message(
-                            file=file_path, message='%s is not referenced in the submission.' % f
+                            file=file_path, message=f'{f} is not referenced in the submission.'
                         )
+                        if is_ext_attr_file(f):
+                            self._add_validation_message(
+                               file=file_path, message=f'{f} might be a file created by tar on MacOS. Set COPYFILE_DISABLE=1 before creating the archive.',
+                               level='hint'
+                            )
 
             return len(self.messages) == 0
         finally:
@@ -218,14 +233,14 @@ class FullSubmissionValidator(Validator):
                 # Delete temporary Directory
                 shutil.rmtree(self.temp_directory)
 
-    def _add_validation_message(self, file, message):
+    def _add_validation_message(self, file, message, **kwargs):
         if self.temp_directory:
             # Remove temp directory from filename and message
             file = self._remove_temp_directory(file)
             message = self._remove_temp_directory(message)
 
         self.add_validation_message(ValidationMessage(
-            file=file, message=message
+            file=file, message=message, **kwargs
         ))
 
     def _remove_temp_directory(self, s):
@@ -243,7 +258,7 @@ class FullSubmissionValidator(Validator):
                     file_name = os.path.join(self.directory, file_name)
                 with open(file_name, 'w') as data_file:
                     yaml.dump({'independent_variables': doc.pop('independent_variables', None),
-                               'dependent_variables': doc.pop('dependent_variables', None)}, data_file, Dumper=Dumper)
+                               'dependent_variables': doc.pop('dependent_variables', None)}, data_file, Dumper=YamlDumper)
 
     def _check_doc(self, doc):
         # Skip empty YAML documents.
@@ -300,6 +315,15 @@ class FullSubmissionValidator(Validator):
                 )
                 return is_valid_submission_doc
 
+            file_size = os.path.getsize(data_file_path)
+            if file_size > INDIVIDUAL_FILE_SIZE_LIMIT: # 10MB limit for each file
+                self._add_validation_message(
+                    file=data_file_path,
+                    message=f"Size of data_file '{doc['data_file']}' ({file_size} bytes) is bigger than the limit of " \
+                            f"{INDIVIDUAL_FILE_SIZE_LIMIT} bytes. Try adding the file as an additional_resource instead."
+                )
+                return is_valid_submission_doc
+
             user_data_file_path = self.submission_file_path if self.single_yaml_file else data_file_path
             user_data_file_path = self._remove_temp_directory(user_data_file_path)
 
@@ -324,7 +348,7 @@ class FullSubmissionValidator(Validator):
 
             # Just try to load YAML data file without validating schema.
             try:
-                contents = yaml.load(open(data_file_path, 'r'), Loader=Loader)
+                contents = yaml.load(open(data_file_path, 'r'), Loader=YamlLoader)
             except (OSError, yaml.YAMLError) as e:
                 problem_type = 'reading' if isinstance(e, OSError) else 'parsing'
                 self._add_validation_message(
